<div class="modal fade" tabindex="-1" role="dialog" id="otree_tools_modal" aria-labelledby="otree_tools_modal_label"
     aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">{{ title }}</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="{{ no_button }}">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <p class="otree-modal-message">{{ message }}</p>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">{{ no_button }}</button>
                <button type="submit" class="btn btn-primary">{{ yes_button }}</button>
            </div>
        </div>
    </div>
</div>
<div class="my-3">
    <button type="button" class="btn btn-primary otree-modal-main-button" data-toggle="modal" data-target="#otree_tools_modal">
        {{ main_button }}
    </button>
</div>