{% with id=widget.attrs.id %}
<div class="form-check">
    <label for="" class="form-check-label">
        <ul class="">
            {% for group, options, index in widget.optgroups %}
            {% for option in options %}
            <li>
                {% include "otree_tools/widgets/multiple_choice_option.html" with widget=option %}
            </li>
            {% endfor %}
            {% endfor %}
        </ul>
    </label>
</div>
{% endwith %}
