<table cellpadding="0" cellspacing="0" border="0" class="table table-striped radiogrid">
    <thead>
        <tr>
            <th>&nbsp;</th>
            {% for value, name in values %}
                <th>{{ name }}</th>
            {% endfor %}
        </tr>
    </thead>
    <tbody>
        {% for name, tr in rows %}
            <tr>
                <td>
                    {{ name }}
                </td>
                {% if tr.template_name %}
                    {% include tr.template_name %}
                {% else %}
                    {{ tr }}
                {% endif %}
            </tr>
        {% endfor %}
    </tbody>
</table>
<style>
    .radiogrid tbody input.form-check-input {
        margin-left:0px;
    }
</style>
