{% extends "otree/BaseAdmin.html" %}
{% load staticfiles  %}
{% block title %}
Update expiration date
{% endblock %}

{% block content %}
<link href=  "{% static 'css/datetimepicker.css' %}" type="text/css" media="all" rel="stylesheet" />
<script type="text/javascript" src="{% static  'js/bootstrap-datetimepicker.js' %}"></script>
<form method="post">
    {{ form.media }}
    {% csrf_token %}
    {% if mturk_errors %}
        <div class="alert alert-danger">{{mturk_errors}}</div>
    {% else %}
        {{ form.as_p }}
    {% endif %}
    <a href="
    {% if view.back_to_HIT %}
    {% url 'assignments_list' view.HITId %}
    {% else %}
    {% url 'hits_list' %}
    {% endif %}
" class="btn btn-default btn-lg active" role="button">Cancel</a>
    <button type="submit" class="btn btn-success btn-lg active">Update</button>
</form>
{% endblock %}

{% block internal_styles %}
{{ block.super }}

{% endblock %}
